@@ -13,7 +13,7 @@ import pandas as pd
 from sqlalchemy import Column, String
 from PIL import Image
 
-from datapipe.types import DataDF, DataSchema, IndexDF
+from datapipe.types import DataDF, DataSchema, MetaSchema, IndexDF
 from datapipe.store.table_store import TableStore
 from datapipe.run_config import RunConfig
 
@@ -120,13 +120,13 @@ class TableStoreFiledir(TableStore):
            дефолтный тип `String(100)`
 
         Args:
-        
+
         filename_pattern -- Путь к файлам в формате fsspec (но без chaining),
         может содержать два типа шаблонов:
           - {id_field} - поле из индекса учитывается как при чтении так и при
             записи
           - * - не попадает в индекс, и стор работает режиме "только чтение"
-        
+
         primary_schema -- дает возможность в явном виде задать типы полей,
         который упоминаются в filename_pattern
 
@@ -177,6 +177,9 @@ class TableStoreFiledir(TableStore):
     def get_primary_schema(self) -> DataSchema:
         return self.primary_schema
 
+    def get_meta_schema(self) -> MetaSchema:
+        return []
+
     def delete_rows(self, idx: IndexDF) -> None:
         # FIXME: Реализовать
         # Do not delete old files for now
